/* eslint-disable @typescript-eslint/no-unused-vars */
import type { CSSProperties } from 'vue'
import type { UploadItem } from './types'
import type { ProgressProps } from 'element-plus'

// ToDo 默认方式改为withDefaults
export const imageUploadProps = {
  // 已上传列表
  modelValue: {
    type: Array as PropType<UploadItem[]>,
    required: true
  },
  // 是否自动上传
  autoUpload: {
    type: Boolean,
    default: true
  },
  // 是否启用拖拽上传
  drag: Boolean,
  // 是否只读
  readonly: Boolean,
  // 是否禁用
  disabled: Boolean,
  // 是否点击预览
  preview: {
    type: Boolean,
    default: true
  },
  // 可上传数量
  limit: {
    type: Number,
    default: 9
  },
  // 是否支持多选
  multiple: {
    type: Boolean,
    default: false
  },
  // 上传类型 ToDo: 图片类型去掉，内部自行限制是否是图片
  accept: {
    type: String,
    default: 'image/png,image/jpeg'
  },
  // 文件大小限制(MB)
  fileSize: {
    type: Number,
    default: 5
  },
  // item 样式  Todo: 改为 width height iconStyle
  itemStyle: Object as PropType<Partial<CSSProperties> | Array<Partial<CSSProperties>>>,
  // 上传按钮样式
  buttonStyle: Object as PropType<Partial<CSSProperties> | Array<Partial<CSSProperties>>>,
  // 上传进度条配置
  progressProps: Object as PropType<ProgressProps>,
  // 上传方法
  // ToDo: 结合项目中cofing文件的文件路径实现，增加上传文件key属性
  uploadFunction: {
    type: Function as PropType<(file: any) => Promise<any>>
  }
}

export type ImageUploadProps = ExtractPropTypes<typeof imageUploadProps>

/* 事件 */
export const imageUploadEmits = {
  // 上传事件
  upload: (_value: UploadItem) => true,
  // 单个删除事件
  remove: (_value: UploadItem) => true,
  // 修改modelValue
  'update:modelValue': (_value: UploadItem[]) => true
}
